# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FunctionParsingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FunctionParsingError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FunctionParsingErrorEnum.FunctionParsingError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FunctionParsingErrorEnum.FunctionParsingError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FunctionParsingErrorEnum.FunctionParsingError]]: ...
        UNSPECIFIED = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 0)
        UNKNOWN = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 1)
        NO_MORE_INPUT = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 2)
        EXPECTED_CHARACTER = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 3)
        UNEXPECTED_SEPARATOR = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 4)
        UNMATCHED_LEFT_BRACKET = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 5)
        UNMATCHED_RIGHT_BRACKET = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 6)
        TOO_MANY_NESTED_FUNCTIONS = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 7)
        MISSING_RIGHT_HAND_OPERAND = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 8)
        INVALID_OPERATOR_NAME = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 9)
        FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 10)
        NO_OPERANDS = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 11)
        TOO_MANY_OPERANDS = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 12)
    UNSPECIFIED = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 0)
    UNKNOWN = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 1)
    NO_MORE_INPUT = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 2)
    EXPECTED_CHARACTER = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 3)
    UNEXPECTED_SEPARATOR = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 4)
    UNMATCHED_LEFT_BRACKET = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 5)
    UNMATCHED_RIGHT_BRACKET = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 6)
    TOO_MANY_NESTED_FUNCTIONS = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 7)
    MISSING_RIGHT_HAND_OPERAND = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 8)
    INVALID_OPERATOR_NAME = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 9)
    FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 10)
    NO_OPERANDS = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 11)
    TOO_MANY_OPERANDS = typing___cast(FunctionParsingErrorEnum.FunctionParsingError, 12)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FunctionParsingErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class BidModifierSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[BidModifierSimulationPoint]: ...

    def __init__(self,
        *,
        points : typing___Optional[typing___Iterable[BidModifierSimulationPoint]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BidModifierSimulationPointList: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"points"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"points",b"points"]) -> None: ...

class CpcBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[CpcBidSimulationPoint]: ...

    def __init__(self,
        *,
        points : typing___Optional[typing___Iterable[CpcBidSimulationPoint]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CpcBidSimulationPointList: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"points"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"points",b"points"]) -> None: ...

class CpvBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[CpvBidSimulationPoint]: ...

    def __init__(self,
        *,
        points : typing___Optional[typing___Iterable[CpvBidSimulationPoint]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CpvBidSimulationPointList: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"points"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"points",b"points"]) -> None: ...

class TargetCpaSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[TargetCpaSimulationPoint]: ...

    def __init__(self,
        *,
        points : typing___Optional[typing___Iterable[TargetCpaSimulationPoint]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetCpaSimulationPointList: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"points"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"points",b"points"]) -> None: ...

class BidModifierSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def biddable_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def biddable_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def parent_biddable_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def parent_biddable_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def parent_clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def parent_cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def parent_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def parent_top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        bid_modifier : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        biddable_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        biddable_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        top_slot_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        parent_biddable_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        parent_biddable_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        parent_clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        parent_cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        parent_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        parent_top_slot_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BidModifierSimulationPoint: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"bid_modifier",u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"impressions",u"parent_biddable_conversions",u"parent_biddable_conversions_value",u"parent_clicks",u"parent_cost_micros",u"parent_impressions",u"parent_top_slot_impressions",u"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_modifier",u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"impressions",u"parent_biddable_conversions",u"parent_biddable_conversions_value",u"parent_clicks",u"parent_cost_micros",u"parent_impressions",u"parent_top_slot_impressions",u"top_slot_impressions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"bid_modifier",b"bid_modifier",u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"parent_biddable_conversions",b"parent_biddable_conversions",u"parent_biddable_conversions_value",b"parent_biddable_conversions_value",u"parent_clicks",b"parent_clicks",u"parent_cost_micros",b"parent_cost_micros",u"parent_impressions",b"parent_impressions",u"parent_top_slot_impressions",b"parent_top_slot_impressions",u"top_slot_impressions",b"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_modifier",b"bid_modifier",u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"parent_biddable_conversions",b"parent_biddable_conversions",u"parent_biddable_conversions_value",b"parent_biddable_conversions_value",u"parent_clicks",b"parent_clicks",u"parent_cost_micros",b"parent_cost_micros",u"parent_impressions",b"parent_impressions",u"parent_top_slot_impressions",b"parent_top_slot_impressions",u"top_slot_impressions",b"top_slot_impressions"]) -> None: ...

class CpcBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def biddable_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def biddable_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        biddable_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        biddable_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        top_slot_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CpcBidSimulationPoint: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"cpc_bid_micros",u"impressions",u"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"cpc_bid_micros",u"impressions",u"top_slot_impressions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"cpc_bid_micros",b"cpc_bid_micros",u"impressions",b"impressions",u"top_slot_impressions",b"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"cpc_bid_micros",b"cpc_bid_micros",u"impressions",b"impressions",u"top_slot_impressions",b"top_slot_impressions"]) -> None: ...

class CpvBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def cpv_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        cpv_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CpvBidSimulationPoint: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cost_micros",u"cpv_bid_micros",u"impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cost_micros",u"cpv_bid_micros",u"impressions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cost_micros",b"cost_micros",u"cpv_bid_micros",b"cpv_bid_micros",u"impressions",b"impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cost_micros",b"cost_micros",u"cpv_bid_micros",b"cpv_bid_micros",u"impressions",b"impressions"]) -> None: ...

class TargetCpaSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def target_cpa_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def biddable_conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def biddable_conversions_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        target_cpa_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        biddable_conversions : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        biddable_conversions_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        clicks : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        top_slot_impressions : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TargetCpaSimulationPoint: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"impressions",u"target_cpa_micros",u"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"biddable_conversions",u"biddable_conversions_value",u"clicks",u"cost_micros",u"impressions",u"target_cpa_micros",u"top_slot_impressions"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"target_cpa_micros",b"target_cpa_micros",u"top_slot_impressions",b"top_slot_impressions"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"biddable_conversions",b"biddable_conversions",u"biddable_conversions_value",b"biddable_conversions_value",u"clicks",b"clicks",u"cost_micros",b"cost_micros",u"impressions",b"impressions",u"target_cpa_micros",b"target_cpa_micros",u"top_slot_impressions",b"top_slot_impressions"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.campaign_experiment_status_pb2 import (
    CampaignExperimentStatusEnum as google___ads___googleads___v1___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum,
)

from google.ads.google_ads.v1.proto.enums.campaign_experiment_traffic_split_type_pb2 import (
    CampaignExperimentTrafficSplitTypeEnum as google___ads___googleads___v1___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class CampaignExperiment(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    traffic_split_type = ... # type: google___ads___googleads___v1___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitType
    status = ... # type: google___ads___googleads___v1___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum.CampaignExperimentStatus

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def campaign_draft(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def description(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def traffic_split_percent(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def experiment_campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def long_running_operation(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def start_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def end_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        campaign_draft : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        description : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        traffic_split_percent : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        traffic_split_type : typing___Optional[google___ads___googleads___v1___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitType] = None,
        experiment_campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        status : typing___Optional[google___ads___googleads___v1___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum.CampaignExperimentStatus] = None,
        long_running_operation : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        start_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        end_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignExperiment: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_draft",u"description",u"end_date",u"experiment_campaign",u"id",u"long_running_operation",u"name",u"start_date",u"traffic_split_percent"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_draft",u"description",u"end_date",u"experiment_campaign",u"id",u"long_running_operation",u"name",u"resource_name",u"start_date",u"status",u"traffic_split_percent",u"traffic_split_type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_draft",b"campaign_draft",u"description",b"description",u"end_date",b"end_date",u"experiment_campaign",b"experiment_campaign",u"id",b"id",u"long_running_operation",b"long_running_operation",u"name",b"name",u"start_date",b"start_date",u"traffic_split_percent",b"traffic_split_percent"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_draft",b"campaign_draft",u"description",b"description",u"end_date",b"end_date",u"experiment_campaign",b"experiment_campaign",u"id",b"id",u"long_running_operation",b"long_running_operation",u"name",b"name",u"resource_name",b"resource_name",u"start_date",b"start_date",u"status",b"status",u"traffic_split_percent",b"traffic_split_percent",u"traffic_split_type",b"traffic_split_type"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ConversionUploadErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ConversionUploadError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ConversionUploadErrorEnum.ConversionUploadError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ConversionUploadErrorEnum.ConversionUploadError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ConversionUploadErrorEnum.ConversionUploadError]]: ...
        UNSPECIFIED = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 0)
        UNKNOWN = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 1)
        TOO_MANY_CONVERSIONS_IN_REQUEST = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 2)
        UNPARSEABLE_GCLID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 3)
        CONVERSION_PRECEDES_GCLID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 4)
        EXPIRED_GCLID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 5)
        TOO_RECENT_GCLID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 6)
        GCLID_NOT_FOUND = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 7)
        UNAUTHORIZED_CUSTOMER = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 8)
        INVALID_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 9)
        TOO_RECENT_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 10)
        CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 11)
        EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 12)
        EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 13)
        ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 14)
        ORDER_ID_ALREADY_IN_USE = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 15)
        DUPLICATE_ORDER_ID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 16)
        TOO_RECENT_CALL = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 17)
        EXPIRED_CALL = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 18)
        CALL_NOT_FOUND = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 19)
        CONVERSION_PRECEDES_CALL = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 20)
        CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 21)
        UNPARSEABLE_CALLERS_PHONE_NUMBER = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 22)
    UNSPECIFIED = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 0)
    UNKNOWN = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 1)
    TOO_MANY_CONVERSIONS_IN_REQUEST = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 2)
    UNPARSEABLE_GCLID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 3)
    CONVERSION_PRECEDES_GCLID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 4)
    EXPIRED_GCLID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 5)
    TOO_RECENT_GCLID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 6)
    GCLID_NOT_FOUND = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 7)
    UNAUTHORIZED_CUSTOMER = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 8)
    INVALID_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 9)
    TOO_RECENT_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 10)
    CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 11)
    EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 12)
    EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 13)
    ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 14)
    ORDER_ID_ALREADY_IN_USE = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 15)
    DUPLICATE_ORDER_ID = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 16)
    TOO_RECENT_CALL = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 17)
    EXPIRED_CALL = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 18)
    CALL_NOT_FOUND = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 19)
    CONVERSION_PRECEDES_CALL = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 20)
    CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 21)
    UNPARSEABLE_CALLERS_PHONE_NUMBER = typing___cast(ConversionUploadErrorEnum.ConversionUploadError, 22)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ConversionUploadErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.keyword_plan_common_pb2 import (
    KeywordPlanHistoricalMetrics as google___ads___googleads___v1___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics,
)

from google.ads.google_ads.v1.proto.enums.keyword_plan_network_pb2 import (
    KeywordPlanNetworkEnum as google___ads___googleads___v1___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GenerateKeywordIdeasRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    keyword_plan_network = ... # type: google___ads___googleads___v1___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum.KeywordPlanNetwork

    @property
    def language(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_constants(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def keyword_and_url_seed(self) -> KeywordAndUrlSeed: ...

    @property
    def keyword_seed(self) -> KeywordSeed: ...

    @property
    def url_seed(self) -> UrlSeed: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        language : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_constants : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        keyword_plan_network : typing___Optional[google___ads___googleads___v1___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum.KeywordPlanNetwork] = None,
        keyword_and_url_seed : typing___Optional[KeywordAndUrlSeed] = None,
        keyword_seed : typing___Optional[KeywordSeed] = None,
        url_seed : typing___Optional[UrlSeed] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateKeywordIdeasRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"keyword_and_url_seed",u"keyword_seed",u"language",u"seed",u"url_seed"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"geo_target_constants",u"keyword_and_url_seed",u"keyword_plan_network",u"keyword_seed",u"language",u"seed",u"url_seed"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"keyword_and_url_seed",b"keyword_and_url_seed",u"keyword_seed",b"keyword_seed",u"language",b"language",u"seed",b"seed",u"url_seed",b"url_seed"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"geo_target_constants",b"geo_target_constants",u"keyword_and_url_seed",b"keyword_and_url_seed",u"keyword_plan_network",b"keyword_plan_network",u"keyword_seed",b"keyword_seed",u"language",b"language",u"seed",b"seed",u"url_seed",b"url_seed"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"seed",b"seed"]) -> typing_extensions___Literal["keyword_and_url_seed","keyword_seed","url_seed"]: ...

class KeywordAndUrlSeed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def keywords(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    def __init__(self,
        *,
        url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        keywords : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordAndUrlSeed: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keywords",u"url"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"url",b"url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keywords",b"keywords",u"url",b"url"]) -> None: ...

class KeywordSeed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def keywords(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    def __init__(self,
        *,
        keywords : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordSeed: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"keywords"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"keywords",b"keywords"]) -> None: ...

class UrlSeed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UrlSeed: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"url"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"url",b"url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"url",b"url"]) -> None: ...

class GenerateKeywordIdeaResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[GenerateKeywordIdeaResult]: ...

    def __init__(self,
        *,
        results : typing___Optional[typing___Iterable[GenerateKeywordIdeaResult]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateKeywordIdeaResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"results"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"results",b"results"]) -> None: ...

class GenerateKeywordIdeaResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def keyword_idea_metrics(self) -> google___ads___googleads___v1___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics: ...

    def __init__(self,
        *,
        text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        keyword_idea_metrics : typing___Optional[google___ads___googleads___v1___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenerateKeywordIdeaResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"keyword_idea_metrics",u"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_idea_metrics",u"text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"keyword_idea_metrics",b"keyword_idea_metrics",u"text",b"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"keyword_idea_metrics",b"keyword_idea_metrics",u"text",b"text"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FeedItemTargetErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FeedItemTargetError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FeedItemTargetErrorEnum.FeedItemTargetError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FeedItemTargetErrorEnum.FeedItemTargetError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FeedItemTargetErrorEnum.FeedItemTargetError]]: ...
        UNSPECIFIED = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 0)
        UNKNOWN = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 1)
        MUST_SET_TARGET_ONEOF_ON_CREATE = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 2)
        FEED_ITEM_TARGET_ALREADY_EXISTS = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 3)
        FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 4)
        TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 5)
        TOO_MANY_SCHEDULES_PER_DAY = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 6)
        CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 7)
    UNSPECIFIED = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 0)
    UNKNOWN = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 1)
    MUST_SET_TARGET_ONEOF_ON_CREATE = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 2)
    FEED_ITEM_TARGET_ALREADY_EXISTS = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 3)
    FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 4)
    TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 5)
    TOO_MANY_SCHEDULES_PER_DAY = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 6)
    CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetError, 7)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemTargetErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FeedItemErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FeedItemError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FeedItemErrorEnum.FeedItemError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FeedItemErrorEnum.FeedItemError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FeedItemErrorEnum.FeedItemError]]: ...
        UNSPECIFIED = typing___cast(FeedItemErrorEnum.FeedItemError, 0)
        UNKNOWN = typing___cast(FeedItemErrorEnum.FeedItemError, 1)
        CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = typing___cast(FeedItemErrorEnum.FeedItemError, 2)
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(FeedItemErrorEnum.FeedItemError, 3)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(FeedItemErrorEnum.FeedItemError, 4)
        KEY_ATTRIBUTES_NOT_FOUND = typing___cast(FeedItemErrorEnum.FeedItemError, 5)
        INVALID_URL = typing___cast(FeedItemErrorEnum.FeedItemError, 6)
        MISSING_KEY_ATTRIBUTES = typing___cast(FeedItemErrorEnum.FeedItemError, 7)
        KEY_ATTRIBUTES_NOT_UNIQUE = typing___cast(FeedItemErrorEnum.FeedItemError, 8)
        CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = typing___cast(FeedItemErrorEnum.FeedItemError, 9)
        SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = typing___cast(FeedItemErrorEnum.FeedItemError, 10)
    UNSPECIFIED = typing___cast(FeedItemErrorEnum.FeedItemError, 0)
    UNKNOWN = typing___cast(FeedItemErrorEnum.FeedItemError, 1)
    CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = typing___cast(FeedItemErrorEnum.FeedItemError, 2)
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(FeedItemErrorEnum.FeedItemError, 3)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(FeedItemErrorEnum.FeedItemError, 4)
    KEY_ATTRIBUTES_NOT_FOUND = typing___cast(FeedItemErrorEnum.FeedItemError, 5)
    INVALID_URL = typing___cast(FeedItemErrorEnum.FeedItemError, 6)
    MISSING_KEY_ATTRIBUTES = typing___cast(FeedItemErrorEnum.FeedItemError, 7)
    KEY_ATTRIBUTES_NOT_UNIQUE = typing___cast(FeedItemErrorEnum.FeedItemError, 8)
    CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = typing___cast(FeedItemErrorEnum.FeedItemError, 9)
    SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = typing___cast(FeedItemErrorEnum.FeedItemError, 10)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



import grpc  # type: ignore
from google.ads.google_ads.v2.services.transports.reach_plan_service_grpc_transport import ReachPlanServiceGrpcTransport
from google.ads.google_ads.v2.proto.services.reach_plan_service_pb2 import ListPlannableLocationsResponse, ListPlannableProductsResponse, GenerateProductMixIdeasResponse, GenerateReachForecastResponse, PlannedProduct, Preferences, Targeting
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar, Text
from google.protobuf.wrappers_pb2 import StringValue, Int64Value, Int32Value
from typing_extensions import TypedDict


class StringValueDict(TypedDict):
    value: Text


class Int64ValueDict(TypedDict):
    value: int


class Int32ValueDict(TypedDict):
    value: int


class ReachPlanServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> ReachPlanServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> ReachPlanServiceClient: ...
    transport: Union[ReachPlanServiceGrpcTransport, Callable[[Credentials, type], ReachPlanServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[ReachPlanServiceGrpcTransport, Callable[[Credentials, type], ReachPlanServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def list_plannable_locations(self, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> ListPlannableLocationsResponse: ...
    def list_plannable_products(self, plannable_location_id: Union[StringValueDict, StringValue], retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> ListPlannableProductsResponse: ...
    def generate_product_mix_ideas(self, customer_id: str, plannable_location_id: Union[StringValueDict, StringValue], currency_code: Union[StringValueDict, StringValue], budget_micros: Union[Int64ValueDict, Int64Value], preferences: Union[Dict[Any, Any], Preferences], retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> GenerateProductMixIdeasResponse: ...
    def generate_reach_forecast(self, customer_id: str, currency_code: Union[StringValueDict, StringValue], campaign_duration: Union[Int32ValueDict, Int32Value], cookie_frequency_cap: Union[Int32ValueDict, Int32Value], min_effective_frequency: Union[Int32ValueDict, Int32Value], targeting: Union[Dict[Any, Any], Targeting], planned_products: List[Union[Dict[Any, Any], PlannedProduct]], retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> GenerateReachForecastResponse: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class RequestErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class RequestError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> RequestErrorEnum.RequestError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[RequestErrorEnum.RequestError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, RequestErrorEnum.RequestError]]: ...
        UNSPECIFIED = typing___cast(RequestErrorEnum.RequestError, 0)
        UNKNOWN = typing___cast(RequestErrorEnum.RequestError, 1)
        RESOURCE_NAME_MISSING = typing___cast(RequestErrorEnum.RequestError, 3)
        RESOURCE_NAME_MALFORMED = typing___cast(RequestErrorEnum.RequestError, 4)
        BAD_RESOURCE_ID = typing___cast(RequestErrorEnum.RequestError, 17)
        INVALID_CUSTOMER_ID = typing___cast(RequestErrorEnum.RequestError, 16)
        OPERATION_REQUIRED = typing___cast(RequestErrorEnum.RequestError, 5)
        RESOURCE_NOT_FOUND = typing___cast(RequestErrorEnum.RequestError, 6)
        INVALID_PAGE_TOKEN = typing___cast(RequestErrorEnum.RequestError, 7)
        EXPIRED_PAGE_TOKEN = typing___cast(RequestErrorEnum.RequestError, 8)
        INVALID_PAGE_SIZE = typing___cast(RequestErrorEnum.RequestError, 22)
        REQUIRED_FIELD_MISSING = typing___cast(RequestErrorEnum.RequestError, 9)
        IMMUTABLE_FIELD = typing___cast(RequestErrorEnum.RequestError, 11)
        TOO_MANY_MUTATE_OPERATIONS = typing___cast(RequestErrorEnum.RequestError, 13)
        CANNOT_BE_EXECUTED_BY_MANAGER_ACCOUNT = typing___cast(RequestErrorEnum.RequestError, 14)
        CANNOT_MODIFY_FOREIGN_FIELD = typing___cast(RequestErrorEnum.RequestError, 15)
        INVALID_ENUM_VALUE = typing___cast(RequestErrorEnum.RequestError, 18)
        DEVELOPER_TOKEN_PARAMETER_MISSING = typing___cast(RequestErrorEnum.RequestError, 19)
        LOGIN_CUSTOMER_ID_PARAMETER_MISSING = typing___cast(RequestErrorEnum.RequestError, 20)
        VALIDATE_ONLY_REQUEST_HAS_PAGE_TOKEN = typing___cast(RequestErrorEnum.RequestError, 21)
        CANNOT_RETURN_SUMMARY_ROW_FOR_REQUEST_WITHOUT_METRICS = typing___cast(RequestErrorEnum.RequestError, 29)
        CANNOT_RETURN_SUMMARY_ROW_FOR_VALIDATE_ONLY_REQUESTS = typing___cast(RequestErrorEnum.RequestError, 30)
        INCONSISTENT_RETURN_SUMMARY_ROW_VALUE = typing___cast(RequestErrorEnum.RequestError, 31)
    UNSPECIFIED = typing___cast(RequestErrorEnum.RequestError, 0)
    UNKNOWN = typing___cast(RequestErrorEnum.RequestError, 1)
    RESOURCE_NAME_MISSING = typing___cast(RequestErrorEnum.RequestError, 3)
    RESOURCE_NAME_MALFORMED = typing___cast(RequestErrorEnum.RequestError, 4)
    BAD_RESOURCE_ID = typing___cast(RequestErrorEnum.RequestError, 17)
    INVALID_CUSTOMER_ID = typing___cast(RequestErrorEnum.RequestError, 16)
    OPERATION_REQUIRED = typing___cast(RequestErrorEnum.RequestError, 5)
    RESOURCE_NOT_FOUND = typing___cast(RequestErrorEnum.RequestError, 6)
    INVALID_PAGE_TOKEN = typing___cast(RequestErrorEnum.RequestError, 7)
    EXPIRED_PAGE_TOKEN = typing___cast(RequestErrorEnum.RequestError, 8)
    INVALID_PAGE_SIZE = typing___cast(RequestErrorEnum.RequestError, 22)
    REQUIRED_FIELD_MISSING = typing___cast(RequestErrorEnum.RequestError, 9)
    IMMUTABLE_FIELD = typing___cast(RequestErrorEnum.RequestError, 11)
    TOO_MANY_MUTATE_OPERATIONS = typing___cast(RequestErrorEnum.RequestError, 13)
    CANNOT_BE_EXECUTED_BY_MANAGER_ACCOUNT = typing___cast(RequestErrorEnum.RequestError, 14)
    CANNOT_MODIFY_FOREIGN_FIELD = typing___cast(RequestErrorEnum.RequestError, 15)
    INVALID_ENUM_VALUE = typing___cast(RequestErrorEnum.RequestError, 18)
    DEVELOPER_TOKEN_PARAMETER_MISSING = typing___cast(RequestErrorEnum.RequestError, 19)
    LOGIN_CUSTOMER_ID_PARAMETER_MISSING = typing___cast(RequestErrorEnum.RequestError, 20)
    VALIDATE_ONLY_REQUEST_HAS_PAGE_TOKEN = typing___cast(RequestErrorEnum.RequestError, 21)
    CANNOT_RETURN_SUMMARY_ROW_FOR_REQUEST_WITHOUT_METRICS = typing___cast(RequestErrorEnum.RequestError, 29)
    CANNOT_RETURN_SUMMARY_ROW_FOR_VALIDATE_ONLY_REQUESTS = typing___cast(RequestErrorEnum.RequestError, 30)
    INCONSISTENT_RETURN_SUMMARY_ROW_VALUE = typing___cast(RequestErrorEnum.RequestError, 31)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RequestErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



from typing import Union
import grpc  # type: ignore
from google.ads.google_ads.v1.proto.errors.errors_pb2 import GoogleAdsFailure as GoogleAdsFailureV1
from google.ads.google_ads.v2.proto.errors.errors_pb2 import GoogleAdsFailure as GoogleAdsFailureV2

class GoogleAdsException(Exception):
    error: grpc.RpcError = ...
    call: grpc.Call = ...
    failure: Union[GoogleAdsFailureV1, GoogleAdsFailureV2] = ...
    request_id: str = ...
    def __init__(self, error: grpc.RpcError, call: grpc.Call, failure: Union[GoogleAdsFailureV1, GoogleAdsFailureV2], request_id: str) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.app_url_operating_system_type_pb2 import (
    AppUrlOperatingSystemTypeEnum as google___ads___googleads___v1___enums___app_url_operating_system_type_pb2___AppUrlOperatingSystemTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class FinalAppUrl(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    os_type = ... # type: google___ads___googleads___v1___enums___app_url_operating_system_type_pb2___AppUrlOperatingSystemTypeEnum.AppUrlOperatingSystemType

    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        os_type : typing___Optional[google___ads___googleads___v1___enums___app_url_operating_system_type_pb2___AppUrlOperatingSystemTypeEnum.AppUrlOperatingSystemType] = None,
        url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FinalAppUrl: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"os_type",u"url"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"url",b"url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"os_type",b"os_type",u"url",b"url"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AdGroupErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AdGroupError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AdGroupErrorEnum.AdGroupError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AdGroupErrorEnum.AdGroupError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AdGroupErrorEnum.AdGroupError]]: ...
        UNSPECIFIED = typing___cast(AdGroupErrorEnum.AdGroupError, 0)
        UNKNOWN = typing___cast(AdGroupErrorEnum.AdGroupError, 1)
        DUPLICATE_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupError, 2)
        INVALID_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupError, 3)
        ADVERTISER_NOT_ON_CONTENT_NETWORK = typing___cast(AdGroupErrorEnum.AdGroupError, 5)
        BID_TOO_BIG = typing___cast(AdGroupErrorEnum.AdGroupError, 6)
        BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = typing___cast(AdGroupErrorEnum.AdGroupError, 7)
        MISSING_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupError, 8)
        ADGROUP_LABEL_DOES_NOT_EXIST = typing___cast(AdGroupErrorEnum.AdGroupError, 9)
        ADGROUP_LABEL_ALREADY_EXISTS = typing___cast(AdGroupErrorEnum.AdGroupError, 10)
        INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = typing___cast(AdGroupErrorEnum.AdGroupError, 11)
        AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = typing___cast(AdGroupErrorEnum.AdGroupError, 12)
        ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = typing___cast(AdGroupErrorEnum.AdGroupError, 13)
        CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = typing___cast(AdGroupErrorEnum.AdGroupError, 14)
    UNSPECIFIED = typing___cast(AdGroupErrorEnum.AdGroupError, 0)
    UNKNOWN = typing___cast(AdGroupErrorEnum.AdGroupError, 1)
    DUPLICATE_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupError, 2)
    INVALID_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupError, 3)
    ADVERTISER_NOT_ON_CONTENT_NETWORK = typing___cast(AdGroupErrorEnum.AdGroupError, 5)
    BID_TOO_BIG = typing___cast(AdGroupErrorEnum.AdGroupError, 6)
    BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = typing___cast(AdGroupErrorEnum.AdGroupError, 7)
    MISSING_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupError, 8)
    ADGROUP_LABEL_DOES_NOT_EXIST = typing___cast(AdGroupErrorEnum.AdGroupError, 9)
    ADGROUP_LABEL_ALREADY_EXISTS = typing___cast(AdGroupErrorEnum.AdGroupError, 10)
    INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = typing___cast(AdGroupErrorEnum.AdGroupError, 11)
    AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = typing___cast(AdGroupErrorEnum.AdGroupError, 12)
    ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = typing___cast(AdGroupErrorEnum.AdGroupError, 13)
    CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = typing___cast(AdGroupErrorEnum.AdGroupError, 14)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.month_of_year_pb2 import (
    MonthOfYearEnum as google___ads___googleads___v2___enums___month_of_year_pb2___MonthOfYearEnum,
)

from google.ads.google_ads.v2.proto.resources.invoice_pb2 import (
    Invoice as google___ads___googleads___v2___resources___invoice_pb2___Invoice,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class ListInvoicesRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    billing_setup = ... # type: typing___Text
    issue_year = ... # type: typing___Text
    issue_month = ... # type: google___ads___googleads___v2___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYear

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        billing_setup : typing___Optional[typing___Text] = None,
        issue_year : typing___Optional[typing___Text] = None,
        issue_month : typing___Optional[google___ads___googleads___v2___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYear] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListInvoicesRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"billing_setup",u"customer_id",u"issue_month",u"issue_year"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"billing_setup",b"billing_setup",u"customer_id",b"customer_id",u"issue_month",b"issue_month",u"issue_year",b"issue_year"]) -> None: ...

class ListInvoicesResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def invoices(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___resources___invoice_pb2___Invoice]: ...

    def __init__(self,
        *,
        invoices : typing___Optional[typing___Iterable[google___ads___googleads___v2___resources___invoice_pb2___Invoice]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListInvoicesResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"invoices"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"invoices",b"invoices"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.customer_pay_per_conversion_eligibility_failure_reason_pb2 import (
    CustomerPayPerConversionEligibilityFailureReasonEnum as google___ads___googleads___v2___enums___customer_pay_per_conversion_eligibility_failure_reason_pb2___CustomerPayPerConversionEligibilityFailureReasonEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class Customer(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    pay_per_conversion_eligibility_failure_reasons = ... # type: google___protobuf___internal___containers___RepeatedScalarFieldContainer[google___ads___googleads___v2___enums___customer_pay_per_conversion_eligibility_failure_reason_pb2___CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason]

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def descriptive_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def time_zone(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def auto_tagging_enabled(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def has_partners_badge(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def manager(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def test_account(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def call_reporting_setting(self) -> CallReportingSetting: ...

    @property
    def conversion_tracking_setting(self) -> ConversionTrackingSetting: ...

    @property
    def remarketing_setting(self) -> RemarketingSetting: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        descriptive_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        currency_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        time_zone : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        final_url_suffix : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        auto_tagging_enabled : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        has_partners_badge : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        manager : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        test_account : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        call_reporting_setting : typing___Optional[CallReportingSetting] = None,
        conversion_tracking_setting : typing___Optional[ConversionTrackingSetting] = None,
        remarketing_setting : typing___Optional[RemarketingSetting] = None,
        pay_per_conversion_eligibility_failure_reasons : typing___Optional[typing___Iterable[google___ads___googleads___v2___enums___customer_pay_per_conversion_eligibility_failure_reason_pb2___CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Customer: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"auto_tagging_enabled",u"call_reporting_setting",u"conversion_tracking_setting",u"currency_code",u"descriptive_name",u"final_url_suffix",u"has_partners_badge",u"id",u"manager",u"remarketing_setting",u"test_account",u"time_zone",u"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auto_tagging_enabled",u"call_reporting_setting",u"conversion_tracking_setting",u"currency_code",u"descriptive_name",u"final_url_suffix",u"has_partners_badge",u"id",u"manager",u"pay_per_conversion_eligibility_failure_reasons",u"remarketing_setting",u"resource_name",u"test_account",u"time_zone",u"tracking_url_template"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"auto_tagging_enabled",b"auto_tagging_enabled",u"call_reporting_setting",b"call_reporting_setting",u"conversion_tracking_setting",b"conversion_tracking_setting",u"currency_code",b"currency_code",u"descriptive_name",b"descriptive_name",u"final_url_suffix",b"final_url_suffix",u"has_partners_badge",b"has_partners_badge",u"id",b"id",u"manager",b"manager",u"remarketing_setting",b"remarketing_setting",u"test_account",b"test_account",u"time_zone",b"time_zone",u"tracking_url_template",b"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auto_tagging_enabled",b"auto_tagging_enabled",u"call_reporting_setting",b"call_reporting_setting",u"conversion_tracking_setting",b"conversion_tracking_setting",u"currency_code",b"currency_code",u"descriptive_name",b"descriptive_name",u"final_url_suffix",b"final_url_suffix",u"has_partners_badge",b"has_partners_badge",u"id",b"id",u"manager",b"manager",u"pay_per_conversion_eligibility_failure_reasons",b"pay_per_conversion_eligibility_failure_reasons",u"remarketing_setting",b"remarketing_setting",u"resource_name",b"resource_name",u"test_account",b"test_account",u"time_zone",b"time_zone",u"tracking_url_template",b"tracking_url_template"]) -> None: ...

class CallReportingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def call_reporting_enabled(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def call_conversion_reporting_enabled(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def call_conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        call_reporting_enabled : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        call_conversion_reporting_enabled : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        call_conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CallReportingSetting: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"call_conversion_action",u"call_conversion_reporting_enabled",u"call_reporting_enabled"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"call_conversion_action",u"call_conversion_reporting_enabled",u"call_reporting_enabled"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"call_conversion_action",b"call_conversion_action",u"call_conversion_reporting_enabled",b"call_conversion_reporting_enabled",u"call_reporting_enabled",b"call_reporting_enabled"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"call_conversion_action",b"call_conversion_action",u"call_conversion_reporting_enabled",b"call_conversion_reporting_enabled",u"call_reporting_enabled",b"call_reporting_enabled"]) -> None: ...

class ConversionTrackingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def conversion_tracking_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cross_account_conversion_tracking_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        conversion_tracking_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cross_account_conversion_tracking_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ConversionTrackingSetting: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_tracking_id",u"cross_account_conversion_tracking_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_tracking_id",u"cross_account_conversion_tracking_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_tracking_id",b"conversion_tracking_id",u"cross_account_conversion_tracking_id",b"cross_account_conversion_tracking_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_tracking_id",b"conversion_tracking_id",u"cross_account_conversion_tracking_id",b"cross_account_conversion_tracking_id"]) -> None: ...

class RemarketingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def google_global_site_tag(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        google_global_site_tag : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RemarketingSetting: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"google_global_site_tag"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"google_global_site_tag"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"google_global_site_tag",b"google_global_site_tag"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"google_global_site_tag",b"google_global_site_tag"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ContentLabelTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ContentLabelType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ContentLabelTypeEnum.ContentLabelType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ContentLabelTypeEnum.ContentLabelType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ContentLabelTypeEnum.ContentLabelType]]: ...
        UNSPECIFIED = typing___cast(ContentLabelTypeEnum.ContentLabelType, 0)
        UNKNOWN = typing___cast(ContentLabelTypeEnum.ContentLabelType, 1)
        SEXUALLY_SUGGESTIVE = typing___cast(ContentLabelTypeEnum.ContentLabelType, 2)
        BELOW_THE_FOLD = typing___cast(ContentLabelTypeEnum.ContentLabelType, 3)
        PARKED_DOMAIN = typing___cast(ContentLabelTypeEnum.ContentLabelType, 4)
        GAME = typing___cast(ContentLabelTypeEnum.ContentLabelType, 5)
        JUVENILE = typing___cast(ContentLabelTypeEnum.ContentLabelType, 6)
        PROFANITY = typing___cast(ContentLabelTypeEnum.ContentLabelType, 7)
        TRAGEDY = typing___cast(ContentLabelTypeEnum.ContentLabelType, 8)
        VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelType, 9)
        VIDEO_RATING_DV_G = typing___cast(ContentLabelTypeEnum.ContentLabelType, 10)
        VIDEO_RATING_DV_PG = typing___cast(ContentLabelTypeEnum.ContentLabelType, 11)
        VIDEO_RATING_DV_T = typing___cast(ContentLabelTypeEnum.ContentLabelType, 12)
        VIDEO_RATING_DV_MA = typing___cast(ContentLabelTypeEnum.ContentLabelType, 13)
        VIDEO_NOT_YET_RATED = typing___cast(ContentLabelTypeEnum.ContentLabelType, 14)
        EMBEDDED_VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelType, 15)
        LIVE_STREAMING_VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelType, 16)
        SOCIAL_ISSUES = typing___cast(ContentLabelTypeEnum.ContentLabelType, 17)
    UNSPECIFIED = typing___cast(ContentLabelTypeEnum.ContentLabelType, 0)
    UNKNOWN = typing___cast(ContentLabelTypeEnum.ContentLabelType, 1)
    SEXUALLY_SUGGESTIVE = typing___cast(ContentLabelTypeEnum.ContentLabelType, 2)
    BELOW_THE_FOLD = typing___cast(ContentLabelTypeEnum.ContentLabelType, 3)
    PARKED_DOMAIN = typing___cast(ContentLabelTypeEnum.ContentLabelType, 4)
    GAME = typing___cast(ContentLabelTypeEnum.ContentLabelType, 5)
    JUVENILE = typing___cast(ContentLabelTypeEnum.ContentLabelType, 6)
    PROFANITY = typing___cast(ContentLabelTypeEnum.ContentLabelType, 7)
    TRAGEDY = typing___cast(ContentLabelTypeEnum.ContentLabelType, 8)
    VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelType, 9)
    VIDEO_RATING_DV_G = typing___cast(ContentLabelTypeEnum.ContentLabelType, 10)
    VIDEO_RATING_DV_PG = typing___cast(ContentLabelTypeEnum.ContentLabelType, 11)
    VIDEO_RATING_DV_T = typing___cast(ContentLabelTypeEnum.ContentLabelType, 12)
    VIDEO_RATING_DV_MA = typing___cast(ContentLabelTypeEnum.ContentLabelType, 13)
    VIDEO_NOT_YET_RATED = typing___cast(ContentLabelTypeEnum.ContentLabelType, 14)
    EMBEDDED_VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelType, 15)
    LIVE_STREAMING_VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelType, 16)
    SOCIAL_ISSUES = typing___cast(ContentLabelTypeEnum.ContentLabelType, 17)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ContentLabelTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class LocationPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class LocationPlaceholderField(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> LocationPlaceholderFieldEnum.LocationPlaceholderField: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[LocationPlaceholderFieldEnum.LocationPlaceholderField]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, LocationPlaceholderFieldEnum.LocationPlaceholderField]]: ...
        UNSPECIFIED = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 0)
        UNKNOWN = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 1)
        BUSINESS_NAME = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 2)
        ADDRESS_LINE_1 = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 3)
        ADDRESS_LINE_2 = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 4)
        CITY = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 5)
        PROVINCE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 6)
        POSTAL_CODE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 7)
        COUNTRY_CODE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 8)
        PHONE_NUMBER = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 9)
    UNSPECIFIED = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 0)
    UNKNOWN = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 1)
    BUSINESS_NAME = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 2)
    ADDRESS_LINE_1 = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 3)
    ADDRESS_LINE_2 = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 4)
    CITY = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 5)
    PROVINCE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 6)
    POSTAL_CODE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 7)
    COUNTRY_CODE = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 8)
    PHONE_NUMBER = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderField, 9)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LocationPlaceholderFieldEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.product_bidding_category_level_pb2 import (
    ProductBiddingCategoryLevelEnum as google___ads___googleads___v2___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum,
)

from google.ads.google_ads.v2.proto.enums.product_bidding_category_status_pb2 import (
    ProductBiddingCategoryStatusEnum as google___ads___googleads___v2___enums___product_bidding_category_status_pb2___ProductBiddingCategoryStatusEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class ProductBiddingCategoryConstant(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    level = ... # type: google___ads___googleads___v2___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel
    status = ... # type: google___ads___googleads___v2___enums___product_bidding_category_status_pb2___ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def product_bidding_category_constant_parent(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def localized_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        country_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        product_bidding_category_constant_parent : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        level : typing___Optional[google___ads___googleads___v2___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel] = None,
        status : typing___Optional[google___ads___googleads___v2___enums___product_bidding_category_status_pb2___ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus] = None,
        language_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        localized_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProductBiddingCategoryConstant: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"country_code",u"id",u"language_code",u"localized_name",u"product_bidding_category_constant_parent"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"country_code",u"id",u"language_code",u"level",u"localized_name",u"product_bidding_category_constant_parent",u"resource_name",u"status"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"country_code",b"country_code",u"id",b"id",u"language_code",b"language_code",u"localized_name",b"localized_name",u"product_bidding_category_constant_parent",b"product_bidding_category_constant_parent"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"country_code",b"country_code",u"id",b"id",u"language_code",b"language_code",u"level",b"level",u"localized_name",b"localized_name",u"product_bidding_category_constant_parent",b"product_bidding_category_constant_parent",u"resource_name",b"resource_name",u"status",b"status"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FeedErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FeedError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FeedErrorEnum.FeedError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FeedErrorEnum.FeedError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FeedErrorEnum.FeedError]]: ...
        UNSPECIFIED = typing___cast(FeedErrorEnum.FeedError, 0)
        UNKNOWN = typing___cast(FeedErrorEnum.FeedError, 1)
        ATTRIBUTE_NAMES_NOT_UNIQUE = typing___cast(FeedErrorEnum.FeedError, 2)
        ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedError, 3)
        CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 4)
        CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 5)
        CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 6)
        CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = typing___cast(FeedErrorEnum.FeedError, 7)
        FEED_REMOVED = typing___cast(FeedErrorEnum.FeedError, 8)
        INVALID_ORIGIN_VALUE = typing___cast(FeedErrorEnum.FeedError, 9)
        FEED_ORIGIN_IS_NOT_USER = typing___cast(FeedErrorEnum.FeedError, 10)
        INVALID_AUTH_TOKEN_FOR_EMAIL = typing___cast(FeedErrorEnum.FeedError, 11)
        INVALID_EMAIL = typing___cast(FeedErrorEnum.FeedError, 12)
        DUPLICATE_FEED_NAME = typing___cast(FeedErrorEnum.FeedError, 13)
        INVALID_FEED_NAME = typing___cast(FeedErrorEnum.FeedError, 14)
        MISSING_OAUTH_INFO = typing___cast(FeedErrorEnum.FeedError, 15)
        NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = typing___cast(FeedErrorEnum.FeedError, 16)
        TOO_MANY_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedError, 17)
        INVALID_BUSINESS_ACCOUNT = typing___cast(FeedErrorEnum.FeedError, 18)
        BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = typing___cast(FeedErrorEnum.FeedError, 19)
        INVALID_AFFILIATE_CHAIN_ID = typing___cast(FeedErrorEnum.FeedError, 20)
        DUPLICATE_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 21)
    UNSPECIFIED = typing___cast(FeedErrorEnum.FeedError, 0)
    UNKNOWN = typing___cast(FeedErrorEnum.FeedError, 1)
    ATTRIBUTE_NAMES_NOT_UNIQUE = typing___cast(FeedErrorEnum.FeedError, 2)
    ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedError, 3)
    CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 4)
    CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 5)
    CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 6)
    CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = typing___cast(FeedErrorEnum.FeedError, 7)
    FEED_REMOVED = typing___cast(FeedErrorEnum.FeedError, 8)
    INVALID_ORIGIN_VALUE = typing___cast(FeedErrorEnum.FeedError, 9)
    FEED_ORIGIN_IS_NOT_USER = typing___cast(FeedErrorEnum.FeedError, 10)
    INVALID_AUTH_TOKEN_FOR_EMAIL = typing___cast(FeedErrorEnum.FeedError, 11)
    INVALID_EMAIL = typing___cast(FeedErrorEnum.FeedError, 12)
    DUPLICATE_FEED_NAME = typing___cast(FeedErrorEnum.FeedError, 13)
    INVALID_FEED_NAME = typing___cast(FeedErrorEnum.FeedError, 14)
    MISSING_OAUTH_INFO = typing___cast(FeedErrorEnum.FeedError, 15)
    NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = typing___cast(FeedErrorEnum.FeedError, 16)
    TOO_MANY_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedError, 17)
    INVALID_BUSINESS_ACCOUNT = typing___cast(FeedErrorEnum.FeedError, 18)
    BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = typing___cast(FeedErrorEnum.FeedError, 19)
    INVALID_AFFILIATE_CHAIN_ID = typing___cast(FeedErrorEnum.FeedError, 20)
    DUPLICATE_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedError, 21)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.resources.geo_target_constant_pb2 import (
    GeoTargetConstant as google___ads___googleads___v1___resources___geo_target_constant_pb2___GeoTargetConstant,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetGeoTargetConstantRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetGeoTargetConstantRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class SuggestGeoTargetConstantsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class LocationNames(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def names(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

        def __init__(self,
            *,
            names : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> SuggestGeoTargetConstantsRequest.LocationNames: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"names"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"names",b"names"]) -> None: ...

    class GeoTargets(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def geo_target_constants(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

        def __init__(self,
            *,
            geo_target_constants : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> SuggestGeoTargetConstantsRequest.GeoTargets: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constants"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constants",b"geo_target_constants"]) -> None: ...


    @property
    def locale(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def location_names(self) -> SuggestGeoTargetConstantsRequest.LocationNames: ...

    @property
    def geo_targets(self) -> SuggestGeoTargetConstantsRequest.GeoTargets: ...

    def __init__(self,
        *,
        locale : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        country_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        location_names : typing___Optional[SuggestGeoTargetConstantsRequest.LocationNames] = None,
        geo_targets : typing___Optional[SuggestGeoTargetConstantsRequest.GeoTargets] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SuggestGeoTargetConstantsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"country_code",u"geo_targets",u"locale",u"location_names",u"query"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"country_code",u"geo_targets",u"locale",u"location_names",u"query"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"country_code",b"country_code",u"geo_targets",b"geo_targets",u"locale",b"locale",u"location_names",b"location_names",u"query",b"query"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"country_code",b"country_code",u"geo_targets",b"geo_targets",u"locale",b"locale",u"location_names",b"location_names",u"query",b"query"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"query",b"query"]) -> typing_extensions___Literal["location_names","geo_targets"]: ...

class SuggestGeoTargetConstantsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def geo_target_constant_suggestions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[GeoTargetConstantSuggestion]: ...

    def __init__(self,
        *,
        geo_target_constant_suggestions : typing___Optional[typing___Iterable[GeoTargetConstantSuggestion]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SuggestGeoTargetConstantsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constant_suggestions"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constant_suggestions",b"geo_target_constant_suggestions"]) -> None: ...

class GeoTargetConstantSuggestion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def locale(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def reach(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def search_term(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_constant(self) -> google___ads___googleads___v1___resources___geo_target_constant_pb2___GeoTargetConstant: ...

    @property
    def geo_target_constant_parents(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___resources___geo_target_constant_pb2___GeoTargetConstant]: ...

    def __init__(self,
        *,
        locale : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        reach : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        search_term : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_constant : typing___Optional[google___ads___googleads___v1___resources___geo_target_constant_pb2___GeoTargetConstant] = None,
        geo_target_constant_parents : typing___Optional[typing___Iterable[google___ads___googleads___v1___resources___geo_target_constant_pb2___GeoTargetConstant]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GeoTargetConstantSuggestion: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"geo_target_constant",u"locale",u"reach",u"search_term"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constant",u"geo_target_constant_parents",u"locale",u"reach",u"search_term"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"geo_target_constant",b"geo_target_constant",u"locale",b"locale",u"reach",b"reach",u"search_term",b"search_term"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constant",b"geo_target_constant",u"geo_target_constant_parents",b"geo_target_constant_parents",u"locale",b"locale",u"reach",b"reach",u"search_term",b"search_term"]) -> None: ...



import grpc  # type: ignore

from .interceptor_mixin import InterceptorMixin
from grpc import UnaryUnaryClientInterceptor
from typing import Callable, Tuple, Optional, TypeVar

_Request = TypeVar("_Request")
_Response = TypeVar("_Response")

class MetadataInterceptor(InterceptorMixin, UnaryUnaryClientInterceptor):
    developer_token_meta: Tuple[str, str] = ...
    login_customer_id_meta: Optional[Tuple[str, str]] = ...
    def __init__(self, developer_token: str, login_customer_id: str) -> None: ...
    def intercept_unary_unary(self, continuation: Callable[[grpc.ClientCallDetails, _Request], _Response], client_call_details: grpc.ClientCallDetails, request: _Request) -> _Response: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter,
)

from google.ads.google_ads.v2.proto.common.feed_common_pb2 import (
    Money as google___ads___googleads___v2___common___feed_common_pb2___Money,
)

from google.ads.google_ads.v2.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v2___common___policy_pb2___PolicyTopicEntry,
)

from google.ads.google_ads.v2.proto.enums.feed_item_quality_approval_status_pb2 import (
    FeedItemQualityApprovalStatusEnum as google___ads___googleads___v2___enums___feed_item_quality_approval_status_pb2___FeedItemQualityApprovalStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.feed_item_quality_disapproval_reason_pb2 import (
    FeedItemQualityDisapprovalReasonEnum as google___ads___googleads___v2___enums___feed_item_quality_disapproval_reason_pb2___FeedItemQualityDisapprovalReasonEnum,
)

from google.ads.google_ads.v2.proto.enums.feed_item_status_pb2 import (
    FeedItemStatusEnum as google___ads___googleads___v2___enums___feed_item_status_pb2___FeedItemStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.feed_item_validation_status_pb2 import (
    FeedItemValidationStatusEnum as google___ads___googleads___v2___enums___feed_item_validation_status_pb2___FeedItemValidationStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.geo_targeting_restriction_pb2 import (
    GeoTargetingRestrictionEnum as google___ads___googleads___v2___enums___geo_targeting_restriction_pb2___GeoTargetingRestrictionEnum,
)

from google.ads.google_ads.v2.proto.enums.placeholder_type_pb2 import (
    PlaceholderTypeEnum as google___ads___googleads___v2___enums___placeholder_type_pb2___PlaceholderTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.policy_approval_status_pb2 import (
    PolicyApprovalStatusEnum as google___ads___googleads___v2___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.policy_review_status_pb2 import (
    PolicyReviewStatusEnum as google___ads___googleads___v2___enums___policy_review_status_pb2___PolicyReviewStatusEnum,
)

from google.ads.google_ads.v2.proto.errors.feed_item_validation_error_pb2 import (
    FeedItemValidationErrorEnum as google___ads___googleads___v2___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class FeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    geo_targeting_restriction = ... # type: google___ads___googleads___v2___enums___geo_targeting_restriction_pb2___GeoTargetingRestrictionEnum.GeoTargetingRestriction
    status = ... # type: google___ads___googleads___v2___enums___feed_item_status_pb2___FeedItemStatusEnum.FeedItemStatus

    @property
    def feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def end_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def attribute_values(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[FeedItemAttributeValue]: ...

    @property
    def url_custom_parameters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]: ...

    @property
    def policy_infos(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[FeedItemPlaceholderPolicyInfo]: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        feed : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        start_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        end_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        attribute_values : typing___Optional[typing___Iterable[FeedItemAttributeValue]] = None,
        geo_targeting_restriction : typing___Optional[google___ads___googleads___v2___enums___geo_targeting_restriction_pb2___GeoTargetingRestrictionEnum.GeoTargetingRestriction] = None,
        url_custom_parameters : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]] = None,
        status : typing___Optional[google___ads___googleads___v2___enums___feed_item_status_pb2___FeedItemStatusEnum.FeedItemStatus] = None,
        policy_infos : typing___Optional[typing___Iterable[FeedItemPlaceholderPolicyInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"end_date_time",u"feed",u"id",u"start_date_time"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"attribute_values",u"end_date_time",u"feed",u"geo_targeting_restriction",u"id",u"policy_infos",u"resource_name",u"start_date_time",u"status",u"url_custom_parameters"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"end_date_time",b"end_date_time",u"feed",b"feed",u"id",b"id",u"start_date_time",b"start_date_time"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"attribute_values",b"attribute_values",u"end_date_time",b"end_date_time",u"feed",b"feed",u"geo_targeting_restriction",b"geo_targeting_restriction",u"id",b"id",u"policy_infos",b"policy_infos",u"resource_name",b"resource_name",u"start_date_time",b"start_date_time",u"status",b"status",u"url_custom_parameters",b"url_custom_parameters"]) -> None: ...

class FeedItemAttributeValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def feed_attribute_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def integer_value(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def boolean_value(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def string_value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def double_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def price_value(self) -> google___ads___googleads___v2___common___feed_common_pb2___Money: ...

    @property
    def integer_values(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___Int64Value]: ...

    @property
    def boolean_values(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___BoolValue]: ...

    @property
    def string_values(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def double_values(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___DoubleValue]: ...

    def __init__(self,
        *,
        feed_attribute_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        integer_value : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        boolean_value : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        string_value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        double_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        price_value : typing___Optional[google___ads___googleads___v2___common___feed_common_pb2___Money] = None,
        integer_values : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___Int64Value]] = None,
        boolean_values : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___BoolValue]] = None,
        string_values : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        double_values : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___DoubleValue]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemAttributeValue: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"boolean_value",u"double_value",u"feed_attribute_id",u"integer_value",u"price_value",u"string_value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"boolean_value",u"boolean_values",u"double_value",u"double_values",u"feed_attribute_id",u"integer_value",u"integer_values",u"price_value",u"string_value",u"string_values"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"boolean_value",b"boolean_value",u"double_value",b"double_value",u"feed_attribute_id",b"feed_attribute_id",u"integer_value",b"integer_value",u"price_value",b"price_value",u"string_value",b"string_value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"boolean_value",b"boolean_value",u"boolean_values",b"boolean_values",u"double_value",b"double_value",u"double_values",b"double_values",u"feed_attribute_id",b"feed_attribute_id",u"integer_value",b"integer_value",u"integer_values",b"integer_values",u"price_value",b"price_value",u"string_value",b"string_value",u"string_values",b"string_values"]) -> None: ...

class FeedItemPlaceholderPolicyInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    placeholder_type_enum = ... # type: google___ads___googleads___v2___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderType
    review_status = ... # type: google___ads___googleads___v2___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatus
    approval_status = ... # type: google___ads___googleads___v2___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatus
    validation_status = ... # type: google___ads___googleads___v2___enums___feed_item_validation_status_pb2___FeedItemValidationStatusEnum.FeedItemValidationStatus
    quality_approval_status = ... # type: google___ads___googleads___v2___enums___feed_item_quality_approval_status_pb2___FeedItemQualityApprovalStatusEnum.FeedItemQualityApprovalStatus
    quality_disapproval_reasons = ... # type: google___protobuf___internal___containers___RepeatedScalarFieldContainer[google___ads___googleads___v2___enums___feed_item_quality_disapproval_reason_pb2___FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason]

    @property
    def feed_mapping_resource_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def policy_topic_entries(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___policy_pb2___PolicyTopicEntry]: ...

    @property
    def validation_errors(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[FeedItemValidationError]: ...

    def __init__(self,
        *,
        placeholder_type_enum : typing___Optional[google___ads___googleads___v2___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderType] = None,
        feed_mapping_resource_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        review_status : typing___Optional[google___ads___googleads___v2___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatus] = None,
        approval_status : typing___Optional[google___ads___googleads___v2___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatus] = None,
        policy_topic_entries : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___policy_pb2___PolicyTopicEntry]] = None,
        validation_status : typing___Optional[google___ads___googleads___v2___enums___feed_item_validation_status_pb2___FeedItemValidationStatusEnum.FeedItemValidationStatus] = None,
        validation_errors : typing___Optional[typing___Iterable[FeedItemValidationError]] = None,
        quality_approval_status : typing___Optional[google___ads___googleads___v2___enums___feed_item_quality_approval_status_pb2___FeedItemQualityApprovalStatusEnum.FeedItemQualityApprovalStatus] = None,
        quality_disapproval_reasons : typing___Optional[typing___Iterable[google___ads___googleads___v2___enums___feed_item_quality_disapproval_reason_pb2___FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemPlaceholderPolicyInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"feed_mapping_resource_name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"approval_status",u"feed_mapping_resource_name",u"placeholder_type_enum",u"policy_topic_entries",u"quality_approval_status",u"quality_disapproval_reasons",u"review_status",u"validation_errors",u"validation_status"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"feed_mapping_resource_name",b"feed_mapping_resource_name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"approval_status",b"approval_status",u"feed_mapping_resource_name",b"feed_mapping_resource_name",u"placeholder_type_enum",b"placeholder_type_enum",u"policy_topic_entries",b"policy_topic_entries",u"quality_approval_status",b"quality_approval_status",u"quality_disapproval_reasons",b"quality_disapproval_reasons",u"review_status",b"review_status",u"validation_errors",b"validation_errors",u"validation_status",b"validation_status"]) -> None: ...

class FeedItemValidationError(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    validation_error = ... # type: google___ads___googleads___v2___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum.FeedItemValidationError

    @property
    def description(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def feed_attribute_ids(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___Int64Value]: ...

    @property
    def extra_info(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        validation_error : typing___Optional[google___ads___googleads___v2___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum.FeedItemValidationError] = None,
        description : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        feed_attribute_ids : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___Int64Value]] = None,
        extra_info : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemValidationError: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"description",u"extra_info"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"description",u"extra_info",u"feed_attribute_ids",u"validation_error"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"description",b"description",u"extra_info",b"extra_info"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"description",b"description",u"extra_info",b"extra_info",u"feed_attribute_ids",b"feed_attribute_ids",u"validation_error",b"validation_error"]) -> None: ...
